# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from quarkupy import Quarkupy, AsyncQuarkupy
from tests.utils import assert_matches_type
from quarkupy._utils import parse_datetime
from quarkupy.types.registry.quark.files import QuarkHistoryItem

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestQuark:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_retrieve(self, client: Quarkupy) -> None:
        quark = client.history.quark.retrieve(
            "id",
        )
        assert_matches_type(QuarkHistoryItem, quark, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_retrieve(self, client: Quarkupy) -> None:
        response = client.history.quark.with_raw_response.retrieve(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        quark = response.parse()
        assert_matches_type(QuarkHistoryItem, quark, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_retrieve(self, client: Quarkupy) -> None:
        with client.history.quark.with_streaming_response.retrieve(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            quark = response.parse()
            assert_matches_type(QuarkHistoryItem, quark, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_retrieve(self, client: Quarkupy) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.history.quark.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip()
    @parametrize
    def test_method_update(self, client: Quarkupy) -> None:
        quark = client.history.quark.update(
            created_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            flow_history_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            identity_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            input={},
            output={},
            quark_history_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            registry_qrn="registry_qrn",
            state={},
            status="New",
        )
        assert_matches_type(QuarkHistoryItem, quark, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_update_with_all_params(self, client: Quarkupy) -> None:
        quark = client.history.quark.update(
            created_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            flow_history_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            identity_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            input={},
            output={},
            quark_history_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            registry_qrn="registry_qrn",
            state={},
            status="New",
            registry_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            runner_task_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            supervisor_task_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            worker_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(QuarkHistoryItem, quark, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_update(self, client: Quarkupy) -> None:
        response = client.history.quark.with_raw_response.update(
            created_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            flow_history_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            identity_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            input={},
            output={},
            quark_history_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            registry_qrn="registry_qrn",
            state={},
            status="New",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        quark = response.parse()
        assert_matches_type(QuarkHistoryItem, quark, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_update(self, client: Quarkupy) -> None:
        with client.history.quark.with_streaming_response.update(
            created_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            flow_history_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            identity_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            input={},
            output={},
            quark_history_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            registry_qrn="registry_qrn",
            state={},
            status="New",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            quark = response.parse()
            assert_matches_type(QuarkHistoryItem, quark, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncQuark:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip()
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncQuarkupy) -> None:
        quark = await async_client.history.quark.retrieve(
            "id",
        )
        assert_matches_type(QuarkHistoryItem, quark, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncQuarkupy) -> None:
        response = await async_client.history.quark.with_raw_response.retrieve(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        quark = await response.parse()
        assert_matches_type(QuarkHistoryItem, quark, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncQuarkupy) -> None:
        async with async_client.history.quark.with_streaming_response.retrieve(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            quark = await response.parse()
            assert_matches_type(QuarkHistoryItem, quark, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncQuarkupy) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.history.quark.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip()
    @parametrize
    async def test_method_update(self, async_client: AsyncQuarkupy) -> None:
        quark = await async_client.history.quark.update(
            created_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            flow_history_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            identity_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            input={},
            output={},
            quark_history_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            registry_qrn="registry_qrn",
            state={},
            status="New",
        )
        assert_matches_type(QuarkHistoryItem, quark, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncQuarkupy) -> None:
        quark = await async_client.history.quark.update(
            created_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            flow_history_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            identity_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            input={},
            output={},
            quark_history_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            registry_qrn="registry_qrn",
            state={},
            status="New",
            registry_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            runner_task_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            supervisor_task_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            worker_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(QuarkHistoryItem, quark, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncQuarkupy) -> None:
        response = await async_client.history.quark.with_raw_response.update(
            created_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            flow_history_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            identity_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            input={},
            output={},
            quark_history_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            registry_qrn="registry_qrn",
            state={},
            status="New",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        quark = await response.parse()
        assert_matches_type(QuarkHistoryItem, quark, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncQuarkupy) -> None:
        async with async_client.history.quark.with_streaming_response.update(
            created_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            flow_history_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            identity_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            input={},
            output={},
            quark_history_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            registry_qrn="registry_qrn",
            state={},
            status="New",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            quark = await response.parse()
            assert_matches_type(QuarkHistoryItem, quark, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from quarkupy import Quarkupy, AsyncQuarkupy
from tests.utils import assert_matches_type
from quarkupy._utils import parse_datetime
from quarkupy.types.history import FlowHistoryItem

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestFlow:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_retrieve(self, client: Quarkupy) -> None:
        flow = client.history.flow.retrieve(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(FlowHistoryItem, flow, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_retrieve(self, client: Quarkupy) -> None:
        response = client.history.flow.with_raw_response.retrieve(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        flow = response.parse()
        assert_matches_type(FlowHistoryItem, flow, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_retrieve(self, client: Quarkupy) -> None:
        with client.history.flow.with_streaming_response.retrieve(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            flow = response.parse()
            assert_matches_type(FlowHistoryItem, flow, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_retrieve(self, client: Quarkupy) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.history.flow.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip()
    @parametrize
    def test_method_update(self, client: Quarkupy) -> None:
        flow = client.history.flow.update(
            created_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            edges=[
                {
                    "source": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                    "target": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                }
            ],
            flow_history_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            identity_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            input={},
            metrics={},
            nodes=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
            registry_qrn="registry_qrn",
            status="New",
            updated_at=parse_datetime("2019-12-27T18:11:19.117Z"),
        )
        assert_matches_type(FlowHistoryItem, flow, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_update_with_all_params(self, client: Quarkupy) -> None:
        flow = client.history.flow.update(
            created_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            edges=[
                {
                    "source": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                    "target": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                    "_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                }
            ],
            flow_history_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            identity_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            input={},
            metrics={},
            nodes=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
            registry_qrn="registry_qrn",
            status="New",
            updated_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            output={},
            registry_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(FlowHistoryItem, flow, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_update(self, client: Quarkupy) -> None:
        response = client.history.flow.with_raw_response.update(
            created_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            edges=[
                {
                    "source": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                    "target": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                }
            ],
            flow_history_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            identity_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            input={},
            metrics={},
            nodes=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
            registry_qrn="registry_qrn",
            status="New",
            updated_at=parse_datetime("2019-12-27T18:11:19.117Z"),
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        flow = response.parse()
        assert_matches_type(FlowHistoryItem, flow, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_update(self, client: Quarkupy) -> None:
        with client.history.flow.with_streaming_response.update(
            created_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            edges=[
                {
                    "source": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                    "target": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                }
            ],
            flow_history_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            identity_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            input={},
            metrics={},
            nodes=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
            registry_qrn="registry_qrn",
            status="New",
            updated_at=parse_datetime("2019-12-27T18:11:19.117Z"),
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            flow = response.parse()
            assert_matches_type(FlowHistoryItem, flow, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncFlow:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip()
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncQuarkupy) -> None:
        flow = await async_client.history.flow.retrieve(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(FlowHistoryItem, flow, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncQuarkupy) -> None:
        response = await async_client.history.flow.with_raw_response.retrieve(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        flow = await response.parse()
        assert_matches_type(FlowHistoryItem, flow, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncQuarkupy) -> None:
        async with async_client.history.flow.with_streaming_response.retrieve(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            flow = await response.parse()
            assert_matches_type(FlowHistoryItem, flow, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncQuarkupy) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.history.flow.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip()
    @parametrize
    async def test_method_update(self, async_client: AsyncQuarkupy) -> None:
        flow = await async_client.history.flow.update(
            created_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            edges=[
                {
                    "source": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                    "target": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                }
            ],
            flow_history_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            identity_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            input={},
            metrics={},
            nodes=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
            registry_qrn="registry_qrn",
            status="New",
            updated_at=parse_datetime("2019-12-27T18:11:19.117Z"),
        )
        assert_matches_type(FlowHistoryItem, flow, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncQuarkupy) -> None:
        flow = await async_client.history.flow.update(
            created_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            edges=[
                {
                    "source": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                    "target": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                    "_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                }
            ],
            flow_history_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            identity_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            input={},
            metrics={},
            nodes=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
            registry_qrn="registry_qrn",
            status="New",
            updated_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            output={},
            registry_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(FlowHistoryItem, flow, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncQuarkupy) -> None:
        response = await async_client.history.flow.with_raw_response.update(
            created_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            edges=[
                {
                    "source": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                    "target": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                }
            ],
            flow_history_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            identity_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            input={},
            metrics={},
            nodes=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
            registry_qrn="registry_qrn",
            status="New",
            updated_at=parse_datetime("2019-12-27T18:11:19.117Z"),
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        flow = await response.parse()
        assert_matches_type(FlowHistoryItem, flow, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncQuarkupy) -> None:
        async with async_client.history.flow.with_streaming_response.update(
            created_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            edges=[
                {
                    "source": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                    "target": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                }
            ],
            flow_history_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            identity_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            input={},
            metrics={},
            nodes=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
            registry_qrn="registry_qrn",
            status="New",
            updated_at=parse_datetime("2019-12-27T18:11:19.117Z"),
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            flow = await response.parse()
            assert_matches_type(FlowHistoryItem, flow, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .context_insert_object_run_params import ContextInsertObjectRunParams as ContextInsertObjectRunParams



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .other import (
    OtherResource,
    AsyncOtherResource,
    OtherResourceWithRawResponse,
    AsyncOtherResourceWithRawResponse,
    OtherResourceWithStreamingResponse,
    AsyncOtherResourceWithStreamingResponse,
)
from .context_insert_objects import (
    ContextInsertObjectsResource,
    AsyncContextInsertObjectsResource,
    ContextInsertObjectsResourceWithRawResponse,
    AsyncContextInsertObjectsResourceWithRawResponse,
    ContextInsertObjectsResourceWithStreamingResponse,
    AsyncContextInsertObjectsResourceWithStreamingResponse,
)

__all__ = [
    "ContextInsertObjectsResource",
    "AsyncContextInsertObjectsResource",
    "ContextInsertObjectsResourceWithRawResponse",
    "AsyncContextInsertObjectsResourceWithRawResponse",
    "ContextInsertObjectsResourceWithStreamingResponse",
    "AsyncContextInsertObjectsResourceWithStreamingResponse",
    "OtherResource",
    "AsyncOtherResource",
    "OtherResourceWithRawResponse",
    "AsyncOtherResourceWithRawResponse",
    "OtherResourceWithStreamingResponse",
    "AsyncOtherResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from quarkupy import Quarkupy, AsyncQuarkupy
from tests.utils import assert_matches_type
from quarkupy.types.registry.quark.files import QuarkHistoryItem

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestSnowflakeRead:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_run(self, client: Quarkupy) -> None:
        snowflake_read = client.registry.quark.databases.snowflake_read.run(
            account="account",
            auth={
                "password": "password",
                "username": "username",
            },
            lattice_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            query="query",
        )
        assert_matches_type(QuarkHistoryItem, snowflake_read, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_run_with_all_params(self, client: Quarkupy) -> None:
        snowflake_read = client.registry.quark.databases.snowflake_read.run(
            account="account",
            auth={
                "password": "password",
                "username": "username",
            },
            lattice_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            query="query",
            opt_database="opt_database",
            opt_role="opt_role",
            opt_schema="opt_schema",
            opt_warehouse="opt_warehouse",
        )
        assert_matches_type(QuarkHistoryItem, snowflake_read, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_run(self, client: Quarkupy) -> None:
        response = client.registry.quark.databases.snowflake_read.with_raw_response.run(
            account="account",
            auth={
                "password": "password",
                "username": "username",
            },
            lattice_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            query="query",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        snowflake_read = response.parse()
        assert_matches_type(QuarkHistoryItem, snowflake_read, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_run(self, client: Quarkupy) -> None:
        with client.registry.quark.databases.snowflake_read.with_streaming_response.run(
            account="account",
            auth={
                "password": "password",
                "username": "username",
            },
            lattice_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            query="query",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            snowflake_read = response.parse()
            assert_matches_type(QuarkHistoryItem, snowflake_read, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncSnowflakeRead:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip()
    @parametrize
    async def test_method_run(self, async_client: AsyncQuarkupy) -> None:
        snowflake_read = await async_client.registry.quark.databases.snowflake_read.run(
            account="account",
            auth={
                "password": "password",
                "username": "username",
            },
            lattice_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            query="query",
        )
        assert_matches_type(QuarkHistoryItem, snowflake_read, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_run_with_all_params(self, async_client: AsyncQuarkupy) -> None:
        snowflake_read = await async_client.registry.quark.databases.snowflake_read.run(
            account="account",
            auth={
                "password": "password",
                "username": "username",
            },
            lattice_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            query="query",
            opt_database="opt_database",
            opt_role="opt_role",
            opt_schema="opt_schema",
            opt_warehouse="opt_warehouse",
        )
        assert_matches_type(QuarkHistoryItem, snowflake_read, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_run(self, async_client: AsyncQuarkupy) -> None:
        response = await async_client.registry.quark.databases.snowflake_read.with_raw_response.run(
            account="account",
            auth={
                "password": "password",
                "username": "username",
            },
            lattice_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            query="query",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        snowflake_read = await response.parse()
        assert_matches_type(QuarkHistoryItem, snowflake_read, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_run(self, async_client: AsyncQuarkupy) -> None:
        async with async_client.registry.quark.databases.snowflake_read.with_streaming_response.run(
            account="account",
            auth={
                "password": "password",
                "username": "username",
            },
            lattice_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            query="query",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            snowflake_read = await response.parse()
            assert_matches_type(QuarkHistoryItem, snowflake_read, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ....._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ....._utils import maybe_transform, async_maybe_transform
from ....._compat import cached_property
from ....._resource import SyncAPIResource, AsyncAPIResource
from ....._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ....._base_client import make_request_options
from .....types.registry.quark.vector import lancedb_search_run_params
from .....types.registry.quark.files.quark_history_item import QuarkHistoryItem

__all__ = ["LancedbSearchResource", "AsyncLancedbSearchResource"]


class LancedbSearchResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> LancedbSearchResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/quarklabsai/quarkupy#accessing-raw-response-data-eg-headers
        """
        return LancedbSearchResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> LancedbSearchResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/quarklabsai/quarkupy#with_streaming_response
        """
        return LancedbSearchResourceWithStreamingResponse(self)

    def run(
        self,
        *,
        lattice_id: str,
        query: lancedb_search_run_params.Query,
        table_name: str,
        opt_uri: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> QuarkHistoryItem:
        """
        Args:
          query: Represents the simple input a Quark/Lattice - usually used for inference

              TODO: Replace this with
              [Issue 23](https://github.com/ProjectBifrost/bifrost/issues/23)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "application/json; charset=utf-8", **(extra_headers or {})}
        return self._post(
            "/registry/quark/vector/lancedb_search/run",
            body=maybe_transform(
                {
                    "lattice_id": lattice_id,
                    "query": query,
                    "table_name": table_name,
                    "opt_uri": opt_uri,
                },
                lancedb_search_run_params.LancedbSearchRunParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=QuarkHistoryItem,
        )


class AsyncLancedbSearchResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncLancedbSearchResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/quarklabsai/quarkupy#accessing-raw-response-data-eg-headers
        """
        return AsyncLancedbSearchResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncLancedbSearchResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/quarklabsai/quarkupy#with_streaming_response
        """
        return AsyncLancedbSearchResourceWithStreamingResponse(self)

    async def run(
        self,
        *,
        lattice_id: str,
        query: lancedb_search_run_params.Query,
        table_name: str,
        opt_uri: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> QuarkHistoryItem:
        """
        Args:
          query: Represents the simple input a Quark/Lattice - usually used for inference

              TODO: Replace this with
              [Issue 23](https://github.com/ProjectBifrost/bifrost/issues/23)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "application/json; charset=utf-8", **(extra_headers or {})}
        return await self._post(
            "/registry/quark/vector/lancedb_search/run",
            body=await async_maybe_transform(
                {
                    "lattice_id": lattice_id,
                    "query": query,
                    "table_name": table_name,
                    "opt_uri": opt_uri,
                },
                lancedb_search_run_params.LancedbSearchRunParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=QuarkHistoryItem,
        )


class LancedbSearchResourceWithRawResponse:
    def __init__(self, lancedb_search: LancedbSearchResource) -> None:
        self._lancedb_search = lancedb_search

        self.run = to_raw_response_wrapper(
            lancedb_search.run,
        )


class AsyncLancedbSearchResourceWithRawResponse:
    def __init__(self, lancedb_search: AsyncLancedbSearchResource) -> None:
        self._lancedb_search = lancedb_search

        self.run = async_to_raw_response_wrapper(
            lancedb_search.run,
        )


class LancedbSearchResourceWithStreamingResponse:
    def __init__(self, lancedb_search: LancedbSearchResource) -> None:
        self._lancedb_search = lancedb_search

        self.run = to_streamed_response_wrapper(
            lancedb_search.run,
        )


class AsyncLancedbSearchResourceWithStreamingResponse:
    def __init__(self, lancedb_search: AsyncLancedbSearchResource) -> None:
        self._lancedb_search = lancedb_search

        self.run = async_to_streamed_response_wrapper(
            lancedb_search.run,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .source import Source as Source
from .data_set_info import DataSetInfo as DataSetInfo
from .source_update_params import SourceUpdateParams as SourceUpdateParams
from .dataset_list_response import DatasetListResponse as DatasetListResponse
from .history_list_response import HistoryListResponse as HistoryListResponse
from .registry_list_response import RegistryListResponse as RegistryListResponse
from .agent_retrieve_response import AgentRetrieveResponse as AgentRetrieveResponse
from .source_list_items_params import SourceListItemsParams as SourceListItemsParams
from .success_response_message import SuccessResponseMessage as SuccessResponseMessage
from .context_list_files_params import ContextListFilesParams as ContextListFilesParams
from .history_list_flows_params import HistoryListFlowsParams as HistoryListFlowsParams
from .history_list_quarks_params import HistoryListQuarksParams as HistoryListQuarksParams
from .source_list_items_response import SourceListItemsResponse as SourceListItemsResponse
from .dataset_retrieve_csv_params import DatasetRetrieveCsvParams as DatasetRetrieveCsvParams
from .history_list_flows_response import HistoryListFlowsResponse as HistoryListFlowsResponse
from .source_add_all_items_params import SourceAddAllItemsParams as SourceAddAllItemsParams
from .dataset_retrieve_json_params import DatasetRetrieveJsonParams as DatasetRetrieveJsonParams
from .history_list_quarks_response import HistoryListQuarksResponse as HistoryListQuarksResponse
from .management_retrieve_response import ManagementRetrieveResponse as ManagementRetrieveResponse
from .dataset_retrieve_arrow_params import DatasetRetrieveArrowParams as DatasetRetrieveArrowParams
from .dataset_retrieve_csv_response import DatasetRetrieveCsvResponse as DatasetRetrieveCsvResponse
from .dataset_retrieve_files_params import DatasetRetrieveFilesParams as DatasetRetrieveFilesParams
from .dataset_retrieve_json_response import DatasetRetrieveJsonResponse as DatasetRetrieveJsonResponse
from .management_retrieve_tokio_params import ManagementRetrieveTokioParams as ManagementRetrieveTokioParams
from .agent_create_chat_rag_demo_params import AgentCreateChatRagDemoParams as AgentCreateChatRagDemoParams
from .management_retrieve_tokio_response import ManagementRetrieveTokioResponse as ManagementRetrieveTokioResponse
from .dataset_retrieve_file_chunks_params import DatasetRetrieveFileChunksParams as DatasetRetrieveFileChunksParams
from .management_retrieve_auth_status_response import (
    ManagementRetrieveAuthStatusResponse as ManagementRetrieveAuthStatusResponse,
)
from .management_retrieve_python_status_response import (
    ManagementRetrievePythonStatusResponse as ManagementRetrievePythonStatusResponse,
)



from __future__ import annotations, absolute_import

from quarkupy.types.history import FlowHistoryItem
from quarkupy.types.registry import QuarkRegistryItem
from quarkupy.types.registry.quark.files import QuarkHistoryItem

from .driver import *
from .inputs import *
from .quarks import *

LatticeStatus = Literal["New", "Scheduled", "Running", "Completed", "Failed"]
QuarkStatus = Literal["New", "Scheduled", "Running", "OutputStaged", "Completed", "Failed"]

__banner__ = f"""
                                                              ________    
     ____                   __   __          __             /\        \  
    / __ \__  ______ ______/ /__/ /   ____ _/ /_  _____    /  \        \ 
   / / / / / / / __ `/ ___/ //_/ /   / __ `/ __ \/ ___/   /    \________\ 
  / /_/ / /_/ / /_/ / /  / ,< / /___/ /_/ / /_/ (__  )    \    /        /  
  \___\_\__,_/\__,_/_/  /_/|_/_____/\__,_/_.___/____/      \  /        / 
                                                            \/________/   
   (c)1985 Quark Labs, Inc. All rights reserved.                       

   Quarkupy 1.0.0
   """

__all__ = [
    "__banner__",
    "QuarkRemoteDriver",
    "LatticeStatus",
    "QuarkStatus",
    "QuarkInput",
    "QuarkHistoryItem",
    "QuarkRegistryItem",
    "FlowHistoryItem",
    "S3ReadCSVQuarkInput",
    "S3ReadWholeFileQuarkInput",
    "DocExtractQuarkInput",
    "TextTemplateInput",
    "OpenAIEmbeddingsInput",
    "OpenAICompletionsInput",
    "DocChunkerQuarkInput",
    "SnowflakeReadInput",
    #"VectorDBIngestInput",
    #"VectorDBSearchInput",
    "OpenAICompletionBaseQuark",
    "OpenAIEmbeddingsQuark",
    "DocExtractQuark",
    "DocChunkerQuark",
    #"VectorDBIngestQuark",
    #"VectorDBSearchQuark",
    "S3ReadCSVQuark",
    "S3ReadWholeFileQuark",
    "TextTemplateBaseQuark",
    "DocChunkerQuark",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from quarkupy import Quarkupy, AsyncQuarkupy
from tests.utils import assert_matches_type
from quarkupy.types.registry import QuarkRegistryItem

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestQuark:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_retrieve(self, client: Quarkupy) -> None:
        quark = client.registry.quark.retrieve(
            name="name",
            cat="cat",
        )
        assert_matches_type(QuarkRegistryItem, quark, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_retrieve(self, client: Quarkupy) -> None:
        response = client.registry.quark.with_raw_response.retrieve(
            name="name",
            cat="cat",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        quark = response.parse()
        assert_matches_type(QuarkRegistryItem, quark, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_retrieve(self, client: Quarkupy) -> None:
        with client.registry.quark.with_streaming_response.retrieve(
            name="name",
            cat="cat",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            quark = response.parse()
            assert_matches_type(QuarkRegistryItem, quark, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_retrieve(self, client: Quarkupy) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `cat` but received ''"):
            client.registry.quark.with_raw_response.retrieve(
                name="name",
                cat="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `name` but received ''"):
            client.registry.quark.with_raw_response.retrieve(
                name="",
                cat="cat",
            )


class TestAsyncQuark:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip()
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncQuarkupy) -> None:
        quark = await async_client.registry.quark.retrieve(
            name="name",
            cat="cat",
        )
        assert_matches_type(QuarkRegistryItem, quark, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncQuarkupy) -> None:
        response = await async_client.registry.quark.with_raw_response.retrieve(
            name="name",
            cat="cat",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        quark = await response.parse()
        assert_matches_type(QuarkRegistryItem, quark, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncQuarkupy) -> None:
        async with async_client.registry.quark.with_streaming_response.retrieve(
            name="name",
            cat="cat",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            quark = await response.parse()
            assert_matches_type(QuarkRegistryItem, quark, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncQuarkupy) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `cat` but received ''"):
            await async_client.registry.quark.with_raw_response.retrieve(
                name="name",
                cat="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `name` but received ''"):
            await async_client.registry.quark.with_raw_response.retrieve(
                name="",
                cat="cat",
            )
